==> bigloo2.0a.tar.gz: bigloo2.0a/runtime/Ieee/char.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime1.9/Ieee/char.scm             */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Jul 21 10:09:50 1992                          */
;*    Last change :  Tue Mar 18 10:22:45 1997 (serrano)                */
;*    -------------------------------------------------------------    */
;*    6.6 Characters (page 24, r4)                                     */
;*=====================================================================*/
 
;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module __r4_characters_6_6
   
   (import  (__error                   "Llib/error.scm"))
   
   (use     (__type                    "Llib/type.scm")
	    (__bigloo                  "Llib/bigloo.scm")
	    (__tvector                 "Llib/tvector.scm")
	    (__r4_equivalence_6_2      "Ieee/equiv.scm")
	    (__r4_numbers_6_5_fixnum   "Ieee/fixnum.scm")
	    (__r4_vectors_6_8          "Ieee/vector.scm")
	    (__r4_strings_6_7          "Ieee/string.scm")
	    (__r4_booleans_6_1         "Ieee/boolean.scm")
	    (__r4_symbols_6_4          "Ieee/symbol.scm")
	    (__r4_pairs_and_lists_6_3  "Ieee/pair-list.scm")

	    (__evenv                   "Eval/evenv.scm"))

   (foreign (macro bool  c-char?                (obj)         "CHARP")
	    (macro       uchar  c-char-upcase   (uchar)       "toupper")
	    (macro       uchar  c-char-downcase (uchar)       "tolower")
	    (infix macro bool  c-char=?         (uchar uchar) "==")
	    (infix macro bool  c-char<?         (uchar uchar) "<")
	    (infix macro bool  c-char>?         (uchar uchar) ">")
	    (infix macro bool  c-char<=?        (uchar uchar) "<=")
	    (infix macro bool  c-char>=?        (uchar uchar) ">=")
	    (macro long  c-char->integer        (uchar)       "")
	    (macro uchar  c-integer->char       (long)        "")
	    (infix macro uchar  c-char-or       (uchar uchar) "|"))
   
   (export  (inline char?::bool             ::obj)
	    (inline char=?::bool            ::uchar ::uchar)
	    (inline char<?::bool            ::uchar ::uchar)
	    (inline char>?::bool            ::uchar ::uchar)
	    (inline char<=?::bool           ::uchar ::uchar)
	    (inline char>=?::bool           ::uchar ::uchar) 
	    (inline char-ci=?::bool         ::uchar ::uchar)
	    (inline char-ci<?::bool         ::uchar ::uchar)
	    (inline char-ci>?::bool         ::uchar ::uchar)
	    (inline char-ci<=?::bool        ::uchar ::uchar)
	    (inline char-ci>=?::bool        ::uchar ::uchar)
	    (inline char-alphabetic?::bool  ::uchar)
	    (inline char-numeric?::bool     ::uchar)
	    (inline char-whitespace?::bool  ::uchar)
	    (inline char-upper-case?::bool  ::uchar)
	    (inline char-lower-case?::bool  ::uchar)
	    (inline char->integer::long     ::uchar)
	    (integer->char::uchar           ::long)
	    (inline integer->char-ur::uchar ::long)
	    (inline char-upcase::uchar      ::uchar)
	    (inline char-downcase::uchar    ::uchar)
	    (inline char-or::uchar          ::uchar ::uchar))
   
   (pragma  (c-char? (predicate-of bchar) no-cfa-top)
	    (char? side-effect-free no-cfa-top)
	    (c-char-upcase side-effect-free)
	    (c-char-downcase side-effect-free)
	    (c-char=? side-effect-free)
	    (c-char<? side-effect-free)
	    (c-char>? side-effect-free)
	    (c-char<=? side-effect-free)
	    (c-char>=? side-effect-free)
	    (c-char->integer side-effect-free)
	    (c-integer->char side-effect-free)
	    (c-char-or side-effect-free)
	    (char=? side-effect-free)
	    (char<? side-effect-free)
	    (char>? side-effect-free)
	    (char<=? side-effect-free)
	    (char>=? side-effect-free)
	    (char-ci=? side-effect-free)
	    (char-ci<? side-effect-free)
	    (char-ci>? side-effect-free)
	    (char-ci<=? side-effect-free)
	    (char-ci>=? side-effect-free)
	    (char-alphabetic? side-effect-free)
	    (char-numeric? side-effect-free)
	    (char-whitespace? side-effect-free)
	    (char-upper-case? side-effect-free)
	    (char-lower-case? side-effect-free)
	    (char->integer side-effect-free)
	    (integer->char side-effect-free)
	    (integer->char-ur side-effect-free)
	    (char-upcase side-effect-free)
	    (char-downcase side-effect-free)
	    (char-or side-effect-free)))
 
;*---------------------------------------------------------------------*/
;*    char? ...                                                        */
;*---------------------------------------------------------------------*/
(define-inline (char? obj)
   (c-char? obj))

;*---------------------------------------------------------------------*/
;*    char=? ...                                                       */
;*---------------------------------------------------------------------*/
(define-inline (char=? char1 char2)
   (c-char=? char1 char2))

;*---------------------------------------------------------------------*/
;*    char<? ...                                                       */
;*---------------------------------------------------------------------*/
(define-inline (char<? char1 char2)
   (c-char<? char1 char2))

;*---------------------------------------------------------------------*/
;*    char>? ...                                                       */
;*---------------------------------------------------------------------*/
(define-inline  (char>? char1 char2)
   (c-char>? char1 char2))

;*---------------------------------------------------------------------*/
;*    char<=? ...                                                      */
;*---------------------------------------------------------------------*/
(define-inline (char<=? char1 char2)
   (c-char<=? char1 char2))

;*---------------------------------------------------------------------*/
;*    char>=? ...                                                      */
;*---------------------------------------------------------------------*/
(define-inline (char>=? char1 char2)
   (c-char>=? char1 char2))

;*---------------------------------------------------------------------*/
;*    char-ci=? ...                                                    */
;*---------------------------------------------------------------------*/
(define-inline (char-ci=? char1 char2)
   (char=? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-ci<? ...                                                    */
;*---------------------------------------------------------------------*/
(define-inline (char-ci<? char1 char2)
   (c-char<? (char-upcase char1) (char-upcase char2))) 

;*---------------------------------------------------------------------*/
;*    char-ci>? ...                                                    */
;*---------------------------------------------------------------------*/
(define-inline  (char-ci>? char1 char2)
   (c-char>? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-ci<=? ...                                                   */
;*---------------------------------------------------------------------*/
(define-inline (char-ci<=? char1 char2)
   (c-char<=? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-ci>=? ...                                                   */
;*---------------------------------------------------------------------*/
(define-inline (char-ci>=? char1 char2)
   (c-char>=? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-alphabetic? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-alphabetic? char)
   (let ((c (char-upcase char)))
      (if (char>=? c #\A)
	  (char<=? c #\Z)
	  #f)))

;*---------------------------------------------------------------------*/
;*    char-numeric? ...                                                */
;*---------------------------------------------------------------------*/
(define-inline (char-numeric? char)
   (if (char>=? char #\0)
       (char<=? char #\9)
       #f))

;*---------------------------------------------------------------------*/
;*    char-withespace? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-whitespace? char)
   (or (char=? char #\space)
       (char=? char #\tab)
       (char=? char #\return)
       (char=? char #\Newline)))

;*---------------------------------------------------------------------*/
;*    char-upper-case? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-upper-case? char)
   (if (char>=? char #\A)
       (char<=? char #\Z)
       #f))

;*---------------------------------------------------------------------*/
;*    char-lower-case? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-lower-case? char)
   (if (char>=? char #\a)
       (char<=? char #\z)
       #f))

;*---------------------------------------------------------------------*/
;*    char->integer ...                                                */
;*---------------------------------------------------------------------*/
(define-inline (char->integer char)
   (c-char->integer char))

;*---------------------------------------------------------------------*/
;*    integer->char ...                                                */
;*---------------------------------------------------------------------*/
(define (integer->char int)
   (if (and (>=fx int 0) (<=fx int 255))
       (c-integer->char int)
       (error "integer->char" "integer out of range" int)))

;*---------------------------------------------------------------------*/
;*    integer->char-ur ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (integer->char-ur int)
   (c-integer->char int))

;*---------------------------------------------------------------------*/
;*    char-upcase ...                                                  */
;*---------------------------------------------------------------------*/
(define-inline  (char-upcase char)
   (c-char-upcase char))

;*---------------------------------------------------------------------*/
;*    char-downcase ...                                                */
;*---------------------------------------------------------------------*/
(define-inline  (char-downcase char)
   (c-char-downcase char))
		     
;*---------------------------------------------------------------------*/
;*    char-or ...                                                      */
;*---------------------------------------------------------------------*/
(define-inline (char-or char1 char2)
   (c-char-or char1 char2))

==> bigloo_2.4b.orig.tar.gz: bigloo2.4b/runtime/Ieee/char.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Ieee/char.scm                */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Jul 21 10:09:50 1992                          */
;*    Last change :  Mon May  7 18:51:06 2001 (serrano)                */
;*    -------------------------------------------------------------    */
;*    6.6 Characters (page 24, r4)                                     */
;*=====================================================================*/
 
;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module __r4_characters_6_6
   
   (import  __error)
   
   (use     __type
	    __bigloo
	    __tvector
	    __r4_equivalence_6_2
	    __r4_numbers_6_5_fixnum
	    __r4_vectors_6_8
	    __r4_strings_6_7
	    __r4_booleans_6_1
	    __r4_symbols_6_4
	    __r4_pairs_and_lists_6_3
	    
	    __evenv)
   
   (extern  (macro c-char?::bool (::obj) "CHARP")
	    (macro c-char-upcase::uchar (::uchar) "toupper")
	    (macro c-char-downcase::uchar (::uchar) "tolower")
	    (infix macro c-char=?::bool (::uchar ::uchar) "==")
	    (infix macro c-char<?::bool (::uchar ::uchar) "<")
	    (infix macro c-char>?::bool (::uchar ::uchar) ">")
	    (infix macro c-char<=?::bool (::uchar ::uchar) "<=")
	    (infix macro c-char>=?::bool (::uchar ::uchar) ">=")
	    (macro c-char->integer::long (::uchar) "")
	    (macro c-integer->char::uchar (::long) "")
	    (infix macro c-char-or::uchar (::uchar ::uchar) "|")
	    (infix macro c-char-and::uchar (::uchar ::uchar) "&")
	    (macro c-char-not::uchar (::uchar) "~"))
   
   (java    (class foreign
	       (method static c-char?::bool (::obj) "CHARP")
	       (method static c-char-upcase::uchar (::uchar) "toupper")
	       (method static c-char-downcase::uchar (::uchar) "tolower")
	       (method static c-char=?::bool (::uchar ::uchar) "CHAR_EQ")
	       (method static c-char<?::bool (::uchar ::uchar) "CHAR_LT")
	       (method static c-char>?::bool (::uchar ::uchar) "CHAR_GT")
	       (method static c-char<=?::bool (::uchar ::uchar) "CHAR_LE")
	       (method static c-char>=?::bool (::uchar ::uchar) "CHAR_GE")
	       (method static c-char->integer::long  (::uchar) "CHAR_TO_INT")
	       (method static c-integer->char::uchar (::long) "INT_TO_CHAR")
	       (method static c-char-or::uchar (::uchar ::uchar) "CHAR_OR")
	       (method static c-char-and::uchar (::uchar ::uchar) "CHAR_AND")
	       (method static c-char-not::uchar (::uchar) "CHAR_NOT")))
   
   (export  (inline char?::bool             ::obj)
	    (inline char=?::bool            ::uchar ::uchar)
	    (inline char<?::bool            ::uchar ::uchar)
	    (inline char>?::bool            ::uchar ::uchar)
	    (inline char<=?::bool           ::uchar ::uchar)
	    (inline char>=?::bool           ::uchar ::uchar) 
	    (inline char-ci=?::bool         ::uchar ::uchar)
	    (inline char-ci<?::bool         ::uchar ::uchar)
	    (inline char-ci>?::bool         ::uchar ::uchar)
	    (inline char-ci<=?::bool        ::uchar ::uchar)
	    (inline char-ci>=?::bool        ::uchar ::uchar)
	    (inline char-alphabetic?::bool  ::uchar)
	    (inline char-numeric?::bool     ::uchar)
	    (inline char-whitespace?::bool  ::uchar)
	    (inline char-upper-case?::bool  ::uchar)
	    (inline char-lower-case?::bool  ::uchar)
	    (inline char->integer::long     ::uchar)
	    (integer->char::uchar           ::long)
	    (inline integer->char-ur::uchar ::long)
	    (inline char-upcase::uchar      ::uchar)
	    (inline char-downcase::uchar    ::uchar)
	    (inline char-or::uchar          ::uchar ::uchar)
	    (inline char-and::uchar         ::uchar ::uchar)
	    (inline char-not::uchar         ::uchar))
   
   (pragma  (c-char? (predicate-of bchar) no-cfa-top nesting)
	    (char? side-effect-free no-cfa-top nesting)
	    (c-char-upcase side-effect-free nesting)
	    (c-char-downcase side-effect-free nesting)
	    (c-char=? side-effect-free nesting)
	    (c-char<? side-effect-free nesting)
	    (c-char>? side-effect-free nesting)
	    (c-char<=? side-effect-free nesting)
	    (c-char>=? side-effect-free nesting)
	    (c-char->integer side-effect-free nesting)
	    (c-integer->char side-effect-free nesting)
	    (c-char-or side-effect-free nesting)
	    (c-char-and side-effect-free nesting)
	    (c-char-not side-effect-free nesting)
	    (char=? side-effect-free nesting)
	    (char<? side-effect-free nesting)
	    (char>? side-effect-free nesting)
	    (char<=? side-effect-free nesting)
	    (char>=? side-effect-free nesting)
	    (char-ci=? side-effect-free nesting)
	    (char-ci<? side-effect-free nesting)
	    (char-ci>? side-effect-free nesting)
	    (char-ci<=? side-effect-free nesting)
	    (char-ci>=? side-effect-free nesting)
	    (char-alphabetic? side-effect-free nesting)
	    (char-numeric? side-effect-free nesting)
	    (char-whitespace? side-effect-free nesting)
	    (char-upper-case? side-effect-free nesting)
	    (char-lower-case? side-effect-free nesting)
	    (char->integer side-effect-free nesting)
	    (integer->char side-effect-free nesting)
	    (integer->char-ur side-effect-free nesting)
	    (char-upcase side-effect-free nesting)
	    (char-downcase side-effect-free nesting)))
 
;*---------------------------------------------------------------------*/
;*    char? ...                                                        */
;*---------------------------------------------------------------------*/
(define-inline (char? obj)
   (c-char? obj))

;*---------------------------------------------------------------------*/
;*    char=? ...                                                       */
;*---------------------------------------------------------------------*/
(define-inline (char=? char1 char2)
   (c-char=? char1 char2))

;*---------------------------------------------------------------------*/
;*    char<? ...                                                       */
;*---------------------------------------------------------------------*/
(define-inline (char<? char1 char2)
   (c-char<? char1 char2))

;*---------------------------------------------------------------------*/
;*    char>? ...                                                       */
;*---------------------------------------------------------------------*/
(define-inline  (char>? char1 char2)
   (c-char>? char1 char2))

;*---------------------------------------------------------------------*/
;*    char<=? ...                                                      */
;*---------------------------------------------------------------------*/
(define-inline (char<=? char1 char2)
   (c-char<=? char1 char2))

;*---------------------------------------------------------------------*/
;*    char>=? ...                                                      */
;*---------------------------------------------------------------------*/
(define-inline (char>=? char1 char2)
   (c-char>=? char1 char2))

;*---------------------------------------------------------------------*/
;*    char-ci=? ...                                                    */
;*---------------------------------------------------------------------*/
(define-inline (char-ci=? char1 char2)
   (char=? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-ci<? ...                                                    */
;*---------------------------------------------------------------------*/
(define-inline (char-ci<? char1 char2)
   (c-char<? (char-upcase char1) (char-upcase char2))) 

;*---------------------------------------------------------------------*/
;*    char-ci>? ...                                                    */
;*---------------------------------------------------------------------*/
(define-inline  (char-ci>? char1 char2)
   (c-char>? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-ci<=? ...                                                   */
;*---------------------------------------------------------------------*/
(define-inline (char-ci<=? char1 char2)
   (c-char<=? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-ci>=? ...                                                   */
;*---------------------------------------------------------------------*/
(define-inline (char-ci>=? char1 char2)
   (c-char>=? (char-upcase char1) (char-upcase char2)))

;*---------------------------------------------------------------------*/
;*    char-alphabetic? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-alphabetic? char)
   (or (and (char>=? char #\A)
            (char<=? char #\Z))
       (and (char>=? char #\a)
            (char<=? char #\z))))

;*---------------------------------------------------------------------*/
;*    char-numeric? ...                                                */
;*---------------------------------------------------------------------*/
(define-inline (char-numeric? char)
   (if (char>=? char #\0)
       (char<=? char #\9)
       #f))

;*---------------------------------------------------------------------*/
;*    char-withespace? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-whitespace? char)
   (or (char=? char #\space)
       (char=? char #\tab)
       (char=? char #\return)
       (char=? char #\Newline)))

;*---------------------------------------------------------------------*/
;*    char-upper-case? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-upper-case? char)
   (if (char>=? char #\A)
       (char<=? char #\Z)
       #f))

;*---------------------------------------------------------------------*/
;*    char-lower-case? ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (char-lower-case? char)
   (if (char>=? char #\a)
       (char<=? char #\z)
       #f))

;*---------------------------------------------------------------------*/
;*    char->integer ...                                                */
;*---------------------------------------------------------------------*/
(define-inline (char->integer char)
   (c-char->integer char))

;*---------------------------------------------------------------------*/
;*    integer->char ...                                                */
;*---------------------------------------------------------------------*/
(define (integer->char int)
   (if (and (>=fx int 0) (<=fx int 255))
       (c-integer->char int)
       (error "integer->char" "integer out of range" int)))

;*---------------------------------------------------------------------*/
;*    integer->char-ur ...                                             */
;*---------------------------------------------------------------------*/
(define-inline (integer->char-ur int)
   (c-integer->char int))

;*---------------------------------------------------------------------*/
;*    char-upcase ...                                                  */
;*---------------------------------------------------------------------*/
(define-inline  (char-upcase char)
   (c-char-upcase char))

;*---------------------------------------------------------------------*/
;*    char-downcase ...                                                */
;*---------------------------------------------------------------------*/
(define-inline  (char-downcase char)
   (c-char-downcase char))
		     
;*---------------------------------------------------------------------*/
;*    char-or ...                                                      */
;*---------------------------------------------------------------------*/
(define-inline (char-or char1 char2)
   (c-char-or char1 char2))

;*---------------------------------------------------------------------*/
;*    char-and ...                                                     */
;*---------------------------------------------------------------------*/
(define-inline (char-and char1 char2)
   (c-char-and char1 char2))

;*---------------------------------------------------------------------*/
;*    char-not ...                                                     */
;*---------------------------------------------------------------------*/
(define-inline (char-not char1)
   (c-char-not char1))
